Data summarization function for TMT labelled MS experiments targeting PTMs.
Source:R/dataSummarizationPTM_TMT.R
dataSummarizationPTM_TMT.RdUtilizes functionality from MSstatsTMT to clean, summarize, and
normalize PTM and protein level data. Imputes missing values, performs
normalization, and summarizes data. PTM data is summarized up to the
modification and protein data is summarized up to the protein level. Takes
as input the output of the included converters (see included raw.input.tmt
data object for required input format).
Usage
dataSummarizationPTM_TMT(
data,
method = "msstats",
global_norm = TRUE,
global_norm.PTM = TRUE,
reference_norm = TRUE,
reference_norm.PTM = TRUE,
remove_norm_channel = TRUE,
remove_empty_channel = TRUE,
MBimpute = TRUE,
MBimpute.PTM = TRUE,
maxQuantileforCensored = NULL,
use_log_file = TRUE,
append = FALSE,
verbose = TRUE,
log_file_path = NULL
)Arguments
- data
Name of the output of MSstatsPTM converter function or peptide-level quantified data from other tools. It should be a list containing one or two data tables, named PTM and PROTEIN for modified and unmodified datasets. The list must at least contain the PTM dataset. The data should have columns ProteinName, PeptideSequence, Charge, PSM, Mixture, TechRepMixture, Run, Channel, Condition, BioReplicate, Intensity
- method
Four different summarization methods to protein-level can be performed : "msstats"(default), "MedianPolish", "Median", "LogSum".
- global_norm
Global median normalization on for unmodified peptide level data (equalizing the medians across all the channels and MS runs). Default is TRUE. It will be performed before protein-level summarization.
- global_norm.PTM
Same as above for modified peptide level data. Default is TRUE.
- reference_norm
Reference channel based normalization between MS runs on unmodified protein level data. TRUE(default) needs at least one reference channel in each MS run, annotated by 'Norm' in Condtion column. It will be performed after protein-level summarization. FALSE will not perform this normalization step. If data only has one run, then reference_norm=FALSE.
- reference_norm.PTM
Same as above for modified peptide level data. Default is TRUE.
- remove_norm_channel
TRUE(default) removes 'Norm' channels from protein level data.
- remove_empty_channel
TRUE(default) removes 'Empty' channels from protein level data.
- MBimpute
only for method="msstats". TRUE (default) imputes missing values by Accelated failure model. FALSE uses minimum value to impute the missing value for each peptide precursor ion.
- MBimpute.PTM
Same as above for modified peptide level data. Default is TRUE
- maxQuantileforCensored
We assume missing values are censored. maxQuantileforCensored is Maximum quantile for deciding censored missing value, for instance, 0.999. Default is Null.
- use_log_file
logical. If TRUE, information about data processing will be saved to a file.
- append
logical. If TRUE, information about data processing will be added to an existing log file.
- verbose
logical. If TRUE, information about data processing will be printed to the console.
- log_file_path
character. Path to a file to which information about data processing will be saved. If not provided, such a file will be created automatically. If
append = TRUE, has to be a valid path to a file.
Examples
head(raw.input.tmt$PTM)
#> ProteinName PeptideSequence Charge PSM Mixture TechRepMixture
#> 1 Protein_12_S703 Peptide491 3 Peptide_491_3 1 1
#> 2 Protein_12_S703 Peptide491 3 Peptide_491_3 1 1
#> 3 Protein_12_S703 Peptide491 3 Peptide_491_3 1 1
#> 4 Protein_12_S703 Peptide491 3 Peptide_491_3 1 1
#> 5 Protein_12_S703 Peptide491 3 Peptide_491_3 1 1
#> 6 Protein_12_S703 Peptide491 3 Peptide_491_3 1 1
#> Run Channel Condition BioReplicate Intensity
#> 1 1_1 128N Condition_2 Condition_2_1 48030.0
#> 2 1_1 129C Condition_4 Condition_4_2 100224.4
#> 3 1_1 131C Condition_3 Condition_3_2 66804.6
#> 4 1_1 130N Condition_1 Condition_1_2 46779.8
#> 5 1_1 128C Condition_6 Condition_6_1 77497.9
#> 6 1_1 126C Condition_4 Condition_4_1 81559.7
head(raw.input.tmt$PROTEIN)
#> ProteinName PeptideSequence Charge PSM Mixture TechRepMixture Run
#> 1 Protein_12 Peptide9121 3 Peptide_9121_3 1 1 1_1
#> 2 Protein_12 Peptide27963 5 Peptide_27963_5 1 1 1_1
#> 3 Protein_12 Peptide28482 4 Peptide_28482_4 1 1 1_1
#> 4 Protein_12 Peptide10940 2 Peptide_10940_2 2 1 2_1
#> 5 Protein_12 Peptide4900 2 Peptide_4900_2 2 1 2_1
#> 6 Protein_12 Peptide4900 3 Peptide_4900_3 2 1 2_1
#> Channel Condition BioReplicate Intensity
#> 1 126C Condition_4 Condition_4_1 10996116.9
#> 2 127C Condition_5 Condition_5_1 56965.1
#> 3 131N Condition_2 Condition_2_2 286121.7
#> 4 131N Condition_2 Condition_2_4 534806.0
#> 5 126C Condition_4 Condition_4_3 1134908.7
#> 6 126C Condition_4 Condition_4_3 1605773.2
quant.tmt.msstatsptm = dataSummarizationPTM_TMT(raw.input.tmt,
method = "msstats",
verbose = FALSE)
#>
|
| | 0%
|
|= | 1%
|
|== | 2%
|
|== | 3%
|
|=== | 5%
|
|==== | 6%
|
|===== | 7%
|
|====== | 8%
|
|======= | 9%
|
|======= | 10%
|
|======== | 12%
|
|========= | 13%
|
|========== | 14%
|
|=========== | 15%
|
|=========== | 16%
|
|============ | 17%
|
|============= | 19%
|
|============== | 20%
|
|=============== | 21%
|
|=============== | 22%
|
|================ | 23%
|
|================= | 24%
|
|================== | 26%
|
|=================== | 27%
|
|==================== | 28%
|
|==================== | 29%
|
|===================== | 30%
|
|====================== | 31%
|
|======================= | 33%
|
|======================== | 34%
|
|======================== | 35%
|
|========================= | 36%
|
|========================== | 37%
|
|=========================== | 38%
|
|============================ | 40%
|
|============================ | 41%
|
|============================= | 42%
|
|============================== | 43%
|
|=============================== | 44%
|
|================================ | 45%
|
|================================= | 47%
|
|================================= | 48%
|
|================================== | 49%
|
|=================================== | 50%
|
|==================================== | 51%
|
|===================================== | 52%
|
|===================================== | 53%
|
|====================================== | 55%
|
|======================================= | 56%
|
|======================================== | 57%
|
|========================================= | 58%
|
|========================================== | 59%
|
|========================================== | 60%
|
|=========================================== | 62%
|
|============================================ | 63%
|
|============================================= | 64%
|
|============================================== | 65%
|
|============================================== | 66%
|
|=============================================== | 67%
|
|================================================ | 69%
|
|================================================= | 70%
|
|================================================== | 71%
|
|================================================== | 72%
|
|=================================================== | 73%
|
|==================================================== | 74%
|
|===================================================== | 76%
|
|====================================================== | 77%
|
|======================================================= | 78%
|
|======================================================= | 79%
|
|======================================================== | 80%
|
|========================================================= | 81%
|
|========================================================== | 83%
|
|=========================================================== | 84%
|
|=========================================================== | 85%
|
|============================================================ | 86%
|
|============================================================= | 87%
|
|============================================================== | 88%
|
|=============================================================== | 90%
|
|=============================================================== | 91%
|
|================================================================ | 92%
|
|================================================================= | 93%
|
|================================================================== | 94%
|
|=================================================================== | 95%
|
|==================================================================== | 97%
|
|==================================================================== | 98%
|
|===================================================================== | 99%
|
|======================================================================| 100%
#>
|
| | 0%
|
|=== | 4%
|
|===== | 7%
|
|======== | 11%
|
|========== | 15%
|
|============= | 19%
|
|================ | 22%
|
|================== | 26%
|
|===================== | 30%
|
|======================= | 33%
|
|========================== | 37%
|
|============================= | 41%
|
|=============================== | 44%
|
|================================== | 48%
|
|==================================== | 52%
|
|======================================= | 56%
|
|========================================= | 59%
|
|============================================ | 63%
|
|=============================================== | 67%
|
|================================================= | 70%
|
|==================================================== | 74%
|
|====================================================== | 78%
|
|========================================================= | 81%
|
|============================================================ | 85%
|
|============================================================== | 89%
|
|================================================================= | 93%
|
|=================================================================== | 96%
|
|======================================================================| 100%
#>
|
| | 0%
|
|= | 1%
|
|== | 2%
|
|== | 4%
|
|=== | 5%
|
|==== | 6%
|
|===== | 7%
|
|====== | 8%
|
|======= | 9%
|
|======= | 11%
|
|======== | 12%
|
|========= | 13%
|
|========== | 14%
|
|=========== | 15%
|
|============ | 16%
|
|============ | 18%
|
|============= | 19%
|
|============== | 20%
|
|=============== | 21%
|
|================ | 22%
|
|================ | 24%
|
|================= | 25%
|
|================== | 26%
|
|=================== | 27%
|
|==================== | 28%
|
|===================== | 29%
|
|===================== | 31%
|
|====================== | 32%
|
|======================= | 33%
|
|======================== | 34%
|
|========================= | 35%
|
|========================== | 36%
|
|========================== | 38%
|
|=========================== | 39%
|
|============================ | 40%
|
|============================= | 41%
|
|============================== | 42%
|
|============================== | 44%
|
|=============================== | 45%
|
|================================ | 46%
|
|================================= | 47%
|
|================================== | 48%
|
|=================================== | 49%
|
|=================================== | 51%
|
|==================================== | 52%
|
|===================================== | 53%
|
|====================================== | 54%
|
|======================================= | 55%
|
|======================================== | 56%
|
|======================================== | 58%
|
|========================================= | 59%
|
|========================================== | 60%
|
|=========================================== | 61%
|
|============================================ | 62%
|
|============================================ | 64%
|
|============================================= | 65%
|
|============================================== | 66%
|
|=============================================== | 67%
|
|================================================ | 68%
|
|================================================= | 69%
|
|================================================= | 71%
|
|================================================== | 72%
|
|=================================================== | 73%
|
|==================================================== | 74%
|
|===================================================== | 75%
|
|====================================================== | 76%
|
|====================================================== | 78%
|
|======================================================= | 79%
|
|======================================================== | 80%
|
|========================================================= | 81%
|
|========================================================== | 82%
|
|========================================================== | 84%
|
|=========================================================== | 85%
|
|============================================================ | 86%
|
|============================================================= | 87%
|
|============================================================== | 88%
|
|=============================================================== | 89%
|
|=============================================================== | 91%
|
|================================================================ | 92%
|
|================================================================= | 93%
|
|================================================================== | 94%
|
|=================================================================== | 95%
|
|==================================================================== | 96%
|
|==================================================================== | 98%
|
|===================================================================== | 99%
|
|======================================================================| 100%
#>
|
| | 0%
|
|= | 1%
|
|== | 2%
|
|=== | 4%
|
|=== | 5%
|
|==== | 6%
|
|===== | 7%
|
|====== | 8%
|
|======= | 10%
|
|======== | 11%
|
|======== | 12%
|
|========= | 13%
|
|========== | 14%
|
|=========== | 16%
|
|============ | 17%
|
|============= | 18%
|
|============= | 19%
|
|============== | 20%
|
|=============== | 22%
|
|================ | 23%
|
|================= | 24%
|
|================== | 25%
|
|=================== | 27%
|
|=================== | 28%
|
|==================== | 29%
|
|===================== | 30%
|
|====================== | 31%
|
|======================= | 33%
|
|======================== | 34%
|
|======================== | 35%
|
|========================= | 36%
|
|========================== | 37%
|
|=========================== | 39%
|
|============================ | 40%
|
|============================= | 41%
|
|============================== | 42%
|
|============================== | 43%
|
|=============================== | 45%
|
|================================ | 46%
|
|================================= | 47%
|
|================================== | 48%
|
|=================================== | 49%
|
|=================================== | 51%
|
|==================================== | 52%
|
|===================================== | 53%
|
|====================================== | 54%
|
|======================================= | 55%
|
|======================================== | 57%
|
|======================================== | 58%
|
|========================================= | 59%
|
|========================================== | 60%
|
|=========================================== | 61%
|
|============================================ | 63%
|
|============================================= | 64%
|
|============================================== | 65%
|
|============================================== | 66%
|
|=============================================== | 67%
|
|================================================ | 69%
|
|================================================= | 70%
|
|================================================== | 71%
|
|=================================================== | 72%
|
|=================================================== | 73%
|
|==================================================== | 75%
|
|===================================================== | 76%
|
|====================================================== | 77%
|
|======================================================= | 78%
|
|======================================================== | 80%
|
|========================================================= | 81%
|
|========================================================= | 82%
|
|========================================================== | 83%
|
|=========================================================== | 84%
|
|============================================================ | 86%
|
|============================================================= | 87%
|
|============================================================== | 88%
|
|============================================================== | 89%
|
|=============================================================== | 90%
|
|================================================================ | 92%
|
|================================================================= | 93%
|
|================================================================== | 94%
|
|=================================================================== | 95%
|
|=================================================================== | 96%
|
|==================================================================== | 98%
|
|===================================================================== | 99%
|
|======================================================================| 100%
head(quant.tmt.msstatsptm$PTM$ProteinLevelData)
#> Mixture TechRepMixture Run Channel Protein Abundance BioReplicate
#> 1 1 1 1_1 126C Protein_1076_Y67 13.53222 Condition_4_1
#> 2 1 1 1_1 126C Protein_1145_T915 12.05299 Condition_4_1
#> 3 1 1 1_1 126C Protein_1146_S328 14.43190 Condition_4_1
#> 4 1 1 1_1 126C Protein_1160_S188 16.17976 Condition_4_1
#> 5 1 1 1_1 126C Protein_1220_Y321 15.69534 Condition_4_1
#> 6 1 1 1_1 126C Protein_1235_S416 16.00939 Condition_4_1
#> Condition
#> 1 Condition_4
#> 2 Condition_4
#> 3 Condition_4
#> 4 Condition_4
#> 5 Condition_4
#> 6 Condition_4