PTMlocate annotates modified sites with associated peptides.
Arguments
- peptide
A string vector of peptide sequences. The peptide sequence does not include its preceding and following AAs.
- uniprot
A string vector of Uniprot identifiers of the peptides' originating proteins. UniProtKB entry isoform sequence is used.
- fasta
A data.table with FASTA information. Output of
tidyFasta.- modResidue
A string. Modifiable amino acid residues.
- modSymbol
A string. Symbol of a modified site.
- rmConfound
A logical.
TRUEremoves confounded unmodified sites,FALSEotherwise. Default isFALSE.
Examples
fasta = tidyFasta(system.file("extdata", "O13297.fasta", package="MSstatsPTM"))
locatePTM("DRVSYIHNDSC*TR", "O13297", fasta, "C", "\\*")
#> Key: <uniprot_iso>
#> uniprot_iso peptide site
#> <char> <char> <char>
#> 1: O13297 DRVSYIHNDSC*TR C467